package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * @Description : 库存移动单主表信息(用于转储类业务)
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2018-11-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_DOC_MOVEMENT_MASTER")
@Api("库存移动单主表信息")
public class WmsMoveMentMaster extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    /**
     * 移动类型:IN=入库,OUT=出库,MOVE=移库
     */
    @Column(name="MOVE_TYPE")
    @ApiParam("移动类型")
    public String moveType;

    /**
     * 业务类型:RC=收货,QC=质检,IN=入库,ZI=杂收,ZO=杂发,
     * VJ=供应商退货,CJ=客户退货,WP=工单领料,WJ=工单退料,
     * MI=移库入库,MO=移库出库,SO=发运
     */
    @Column(name="TYPE")
    @ApiParam("业务类型")
    public String type;

    /**
     * 状态:0=新建,10=处理中
     * ,20=已完成,90=已关闭,91=已取消
     */
    @Column(name="STATUS")
    @ApiParam(value = "状态", example = "0")
    public Integer status;

    @Column(name="CUSTOMER_NO")
    @ApiParam("客户编号")
    public String customerNo;

    @Column(name="VENDOR_NO")
    @ApiParam("供应商编号")
    public String vendorNo;

    @Column(name="VERSION")
    @ApiParam("版本")
    public String version;

    @Column(name="SRC")
    @ApiParam("单据来源")
    public String src;

    @Column(name="SRC_NO")
    @ApiParam("关联单据")
    public String srcNo;

    @Column(name="ERP_ORDERNO")
    @ApiParam("ERP单号")
    public String erpOrderNo;

    /**
     * 单据类型:WO=工单配料
     */
    @Column(name="ORDER_TYPE")
    @ApiParam("单据类型")
    public String orderType;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="QTY")
    @ApiParam(value = "需求数量", example = "0")
    public Double qty;
}
